/*
 * Copyright 2016-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.intent;

import org.onosproject.nemo.model.intent.CommonRpcResult.Code;

/**
 * Representation of the base of output builder.
 */
public class DefaultOutputBuilderBase {

    /**
     * Message for the builder to use.
     */
    protected String message;
    /**
     * Result code for the builder to use.
     */
    protected Code resultCode;

    /**
     * Sets the message for the builder to use.
     *
     * @param msg message to set
     * @return self
     */
    public DefaultOutputBuilderBase message(String msg) {
        message = msg;
        return this;
    }

    /**
     * Sets the result code for the builder to use.
     *
     * @param code result code to set
     * @return self
     */
    public DefaultOutputBuilderBase resultCode(Code code) {
        resultCode = code;
        return this;
    }
}