package org.onosproject.nemo.model.object.node.instance;

import static junit.framework.Assert.assertEquals;

import org.junit.Test;
import org.onosproject.nemo.model.common.PropertyName;
import com.google.common.testing.EqualsTester;

/**
 * Unit tests for {@link PropertyBuilder}.
 */
public class PropertyBuilderTest {

    private static final String NAME = "SomeName";
    private static final String OTHER_NAME = "OtherName";
    private static final String NAME_ERROR_MSG = "name not set";
    private static final String KEY_ERROR_MSG = "key not set";
    private PropertyKey key;
    private PropertyName name;
    private PropertyName otherName;
    private Property listParam;
    private Property def;
    private Property copy;
    private Property diff;

    @Test
    public void buildPropertyWithPropertyKey() {
        name = new PropertyName(NAME);
        key = new PropertyKey(name);
        listParam = new PropertyBuilder()
                .key(key)
                .build();
        def = new PropertyBuilder()
                .key(key)
                .addAugmentation(Property.class, listParam)
                .build();
        def = new PropertyBuilder(def)
                .addAugmentation(Property.class, null)
                .build();
        assertEquals(NAME_ERROR_MSG, name, def.getPropertyName());
        assertEquals(KEY_ERROR_MSG, key, def.getKey());
    }

    @Test
    public void buildPropertyWithPropertyName() {
        name = new PropertyName(NAME);
        key = new PropertyKey(name);
        listParam = new PropertyBuilder()
                .propertyName(name)
                .build();
        def = new PropertyBuilder()
                .propertyName(name)
                .addAugmentation(Property.class, listParam)
                .build();
        def = new PropertyBuilder(def)
                .addAugmentation(Property.class, null)
                .build();
        assertEquals(NAME_ERROR_MSG, name, def.getPropertyName());
        assertEquals(KEY_ERROR_MSG, key, def.getKey());
    }

    @Test
    public void fromPropertyWithPropertyKey() {
        name = new PropertyName(NAME);
        key = new PropertyKey(name);
        def = new PropertyBuilder()
                .key(key)
                .build();
        copy = new PropertyBuilder(def).build();
        assertEquals(NAME_ERROR_MSG, name, copy.getPropertyName());
        assertEquals(KEY_ERROR_MSG, key, copy.getKey());
    }

    @Test
    public void fromPropertyWithPropertyName() {
        name = new PropertyName(NAME);
        key = new PropertyKey(name);
        def = new PropertyBuilder()
                .propertyName(name)
                .build();
        copy = new PropertyBuilder(def).build();
        assertEquals(NAME_ERROR_MSG, name, copy.getPropertyName());
        assertEquals(KEY_ERROR_MSG, key, copy.getKey());
    }

    @Test
    public void equality() {
        name = new PropertyName(NAME);
        def = new PropertyBuilder()
                .propertyName(name)
                .build();
        copy = new PropertyBuilder()
                .propertyName(name)
                .build();
        otherName = new PropertyName(OTHER_NAME);
        diff = new PropertyBuilder()
                .propertyName(otherName)
                .build();
        new EqualsTester()
                .addEqualityGroup(def, copy)
                .addEqualityGroup(diff)
                .testEquals();
    }
}